@@ -1,5 +1,5 @@
 import torch
-from model.mlp import mlp
+from contract_nli.model.mlp import mlp
 from torch import nn
 from torch.nn import functional as F
 
